@@ -1,11 +1,6 @@
 package Tapper::Reports::Web::Controller::Base;
-BEGIN {
-  $Tapper::Reports::Web::Controller::Base::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::Web::Controller::Base::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Reports::Web::Controller::Base::VERSION = '5.0.0';
 use strict;
 use warnings;
 
@@ -38,6 +33,10 @@ sub begin :Private
 {
         my ( $self, $c ) = @_;
 
+        require Tapper::Config;
+        if (Tapper::Config->subconfig->{web}->{we_have_a_problem}) {
+                $c->stash->{we_have_a_problem} = Tapper::Config->subconfig->{web}->{we_have_a_problem};
+        }
         $c->stash->{logo}   = Tapper::Config->subconfig->{web}{logo};
         $c->stash->{title}  = Tapper::Config->subconfig->{web}{title};
         $c->stash->{footer} = Tapper::Config->subconfig->{web}{footer};
@@ -47,9 +46,10 @@ sub begin :Private
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -75,17 +75,26 @@ number of days.
 
 @return url part
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
