@@ -1,11 +1,6 @@
 package Tapper::Reports::Web::Controller::Root;
-BEGIN {
-  $Tapper::Reports::Web::Controller::Root::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::Web::Controller::Root::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Reports::Web::Controller::Root::VERSION = '5.0.0';
 use strict;
 use warnings;
 use parent 'Catalyst::Controller';
@@ -40,16 +35,34 @@ sub default :Path
         $c->response->status(404);
 }
 
+sub end : ActionClass('RenderView') {
+
+    my ( $self, $or_c ) = @_;
+
+    if (
+           !$or_c->response->body
+        && ( $or_c->res->status < 300 || $or_c->res->status > 399 )
+        && ( $or_c->res->status != 204 )
+    ) {
+        if ( $or_c->req->params->{json} ) {
+            $or_c->forward('Tapper::Reports::Web::View::JSON');
+        }
+        else {
+            $or_c->forward('Tapper::Reports::Web::View::Mason');
+        }
+    }
+
+    return 1;
+
+}
+
 1;
 
-sub end : ActionClass('RenderView') {}
-
-
-
+__END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -77,21 +90,26 @@ Steffen Schwigon,,,
 
 This program is released under the following license: freebsd
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
-
-__END__
-
-
