@@ -1,11 +1,6 @@
 package Tapper::Reports::Web::Controller::Tapper;
-BEGIN {
-  $Tapper::Reports::Web::Controller::Tapper::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::Web::Controller::Tapper::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Reports::Web::Controller::Tapper::VERSION = '5.0.0';
 use strict;
 use warnings;
 use 5.010;
@@ -60,9 +55,10 @@ sub auto :Private
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -77,17 +73,26 @@ return anything. It is called automatically from Catalyst with an object
 reference ($self) and the catalyst context. Thus you also don't need to
 worry about parameters.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
