@@ -1,11 +1,6 @@
 package Tapper::Reports::Web::Controller::Tapper::Overview;
-BEGIN {
-  $Tapper::Reports::Web::Controller::Tapper::Overview::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::Web::Controller::Tapper::Overview::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Reports::Web::Controller::Tapper::Overview::VERSION = '5.0.0';
 use parent 'Tapper::Reports::Web::Controller::Base';
 use DateTime;
 use Tapper::Reports::Web::Util::Filter::Overview;
@@ -37,7 +32,7 @@ sub recently_used_suites
         } else {
                 $timeframe = DateTime->now->subtract(weeks => 12);
         }
-        my $dtf = $c->model("ReportsDB")->storage->datetime_parser;
+        my $dtf = $c->model("TestrunDB")->storage->datetime_parser;
         $suite_rs  = $suite_rs->search({'reports.created_at' => {'>=' => $dtf->format_datetime($timeframe) }});
         return $suite_rs;
 }
@@ -73,7 +68,7 @@ sub suite
 
         my %search_options    = ( prefetch => ['reports'] );
 
-        my $suite_rs = $c->model('ReportsDB')->resultset('Suite')->search($filter_condition->{early}, { %search_options } );
+        my $suite_rs = $c->model('TestrunDB')->resultset('Suite')->search($filter_condition->{early}, { %search_options } );
         foreach my $filter (@{$filter_condition->{late}}) {
                 $suite_rs = $suite_rs->search($filter);
         }
@@ -88,7 +83,7 @@ sub host
 {
         my ( $self, $c, $filter_condition ) = @_;
 
-        my $reports = $c->model('ReportsDB')->resultset('Report')->search($filter_condition->{early},
+        my $reports = $c->model('TestrunDB')->resultset('Report')->search($filter_condition->{early},
                                                                           { columns => [ qw/machine_name/ ],
                                                                             distinct => 1,
                                                                           });
@@ -171,25 +166,35 @@ sub prepare_navi : Private
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
 Tapper::Reports::Web::Controller::Tapper::Overview
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
