@@ -1,11 +1,6 @@
 package Tapper::Reports::Web::Controller::Tapper::Preconditions;
-BEGIN {
-  $Tapper::Reports::Web::Controller::Tapper::Preconditions::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::Web::Controller::Tapper::Preconditions::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Reports::Web::Controller::Tapper::Preconditions::VERSION = '5.0.0';
 use strict;
 use warnings;
 
@@ -92,9 +87,10 @@ sub new_create : Chained('base') :PathPart('create') :Args(0) :FormConfig
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -120,17 +116,26 @@ Steffen Schwigon,,,
 
 This program is released under the following license: freebsd
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
