@@ -1,11 +1,6 @@
 package Tapper::Reports::Web::Controller::Tapper::ReportFile::Id;
-BEGIN {
-  $Tapper::Reports::Web::Controller::Tapper::ReportFile::Id::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::Web::Controller::Tapper::ReportFile::Id::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Reports::Web::Controller::Tapper::ReportFile::Id::VERSION = '5.0.0';
 use parent 'Tapper::Reports::Web::Controller::Base';
 use HTML::FromANSI ();
 
@@ -20,7 +15,7 @@ our $ANSI2HTML_POST = '</body>';
 sub index :Path :CaptureArgs(2)
 {
         my ( $self, $c, $file_id, $viewmode ) = @_;
-        $c->stash->{reportfile} = $c->model('ReportsDB')->resultset('ReportFile')->find($file_id);
+        $c->stash->{reportfile} = $c->model('TestrunDB')->resultset('ReportFile')->find($file_id);
 
         if (not $c->stash->{reportfile})
         {
@@ -95,25 +90,35 @@ sub filter
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
 Tapper::Reports::Web::Controller::Tapper::ReportFile::Id
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
