@@ -1,11 +1,6 @@
 package Tapper::Reports::Web::Controller::Tapper::Reports::Id;
-BEGIN {
-  $Tapper::Reports::Web::Controller::Tapper::Reports::Id::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::Web::Controller::Tapper::Reports::Id::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Reports::Web::Controller::Tapper::Reports::Id::VERSION = '5.0.0';
 use 5.010;
 use strict;
 use warnings;
@@ -91,7 +86,7 @@ sub index :Path :Args(1)
         $c->stash->{reportlist_rga} = {};
         $c->stash->{reportlist_rgt} = {};
         $c->stash->{overview}       = undef;
-        $c->stash->{report}         = $c->model('ReportsDB')->resultset('Report')->find($report_id);
+        $c->stash->{report}         = $c->model('TestrunDB')->resultset('Report')->find($report_id);
 
         if (not $c->stash->{report}) {
                 $c->response->body("No such report");
@@ -100,7 +95,7 @@ sub index :Path :Args(1)
         }
 
         if (not $c->stash->{report}->suite) {
-                $c->response->body("No such testsuite with id: ". $c->stash->{report}->suite_id);
+                $c->response->body("No such testsuite with id: ". ($c->stash->{report}->suite_id // ""));
                 $c->stash->{title} = "No such testsuite";
                 return;
         }
@@ -112,8 +107,8 @@ sub index :Path :Args(1)
         my $util_report = Tapper::Reports::Web::Util::Report->new();
 
         if (my $rga = $c->stash->{report}->reportgrouparbitrary) {
-                #my $rga_reports = $c->model('ReportsDB')->resultset('ReportgroupArbitrary')->search ({ arbitrary_id => $rga->arbitrary_id });
-                my $rga_reports = $c->model('ReportsDB')->resultset('Report')->search
+                #my $rga_reports = $c->model('TestrunDB')->resultset('ReportgroupArbitrary')->search ({ arbitrary_id => $rga->arbitrary_id });
+                my $rga_reports = $c->model('TestrunDB')->resultset('Report')->search
                     (
                      {
                       "reportgrouparbitrary.arbitrary_id" => $rga->arbitrary_id
@@ -136,8 +131,8 @@ sub index :Path :Args(1)
         }
 
         if (my $rgt = $c->stash->{report}->reportgrouptestrun) {
-                #my $rgt_reports = $c->model('ReportsDB')->resultset('ReportgroupTestrun')->search ({ testrun_id => $rgt->testrun_id });
-                my $rgt_reports = $c->model('ReportsDB')->resultset('Report')->search
+                #my $rgt_reports = $c->model('TestrunDB')->resultset('ReportgroupTestrun')->search ({ testrun_id => $rgt->testrun_id });
+                my $rgt_reports = $c->model('TestrunDB')->resultset('Report')->search
                     (
                      {
                       "reportgrouptestrun.testrun_id" => $rgt->testrun_id
@@ -182,9 +177,10 @@ sub index :Path :Args(1)
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -199,17 +195,26 @@ Generate config for showing metareport image associated to given report.
 @return success - hash containing (url, img, alt, headline)
 @return error   - empty list
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
