@@ -1,11 +1,6 @@
 package Tapper::Reports::Web::Controller::Tapper::Reports::Tap;
-BEGIN {
-  $Tapper::Reports::Web::Controller::Tapper::Reports::Tap::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::Web::Controller::Tapper::Reports::Tap::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Reports::Web::Controller::Tapper::Reports::Tap::VERSION = '5.0.0';
 use strict;
 use warnings;
 
@@ -15,7 +10,7 @@ sub index :Path :Args(1)
 {
         my ( $self, $c, $report_id ) = @_;
 
-        my $report = $c->model('ReportsDB')->resultset('Report')->find($report_id);
+        my $report = $c->model('TestrunDB')->resultset('Report')->find($report_id);
 
         if ($report) {
                 if ($report->tap && $report->tap->tap_is_archive) {
@@ -36,25 +31,35 @@ sub index :Path :Args(1)
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
 Tapper::Reports::Web::Controller::Tapper::Reports::Tap
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
