@@ -1,11 +1,6 @@
 package Tapper::Reports::Web::Controller::Tapper::Rss;
-BEGIN {
-  $Tapper::Reports::Web::Controller::Tapper::Rss::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::Web::Controller::Tapper::Rss::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Reports::Web::Controller::Tapper::Rss::VERSION = '5.0.0';
 use XML::Feed;
 use DateTime;
 use Tapper::Reports::Web::Util::Filter::Report;
@@ -21,7 +16,7 @@ sub index :Path :Args()
         my ($self,$c, @args) = @_;
 
         my $filter = Tapper::Reports::Web::Util::Filter::Report->new(context => $c);
-        my $dtf = $c->model("ReportsDB")->storage->datetime_parser;
+        my $dtf = $c->model("TestrunDB")->storage->datetime_parser;
 
         my $feed = XML::Feed->new('RSS');
         $feed->title( 'Tapper RSS Feed' );
@@ -49,7 +44,7 @@ sub index :Path :Args()
         }
 
 
-        my $reports = $c->model('ReportsDB')->resultset('Report')->search
+        my $reports = $c->model('TestrunDB')->resultset('Report')->search
           (
            $filter_condition->{early},
            {
@@ -59,7 +54,6 @@ sub index :Path :Args()
                                machine_name
                                success_ratio
                                successgrade
-                               reviewed_successgrade
                                total
                             )],
            }
@@ -88,11 +82,11 @@ sub index :Path :Args()
 
 1;
 
-
+__END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -126,21 +120,26 @@ Steffen Schwigon,,,
 
 This program is released under the following license: freebsd
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
-
-__END__
-
-
