@@ -1,11 +1,6 @@
 package Tapper::Reports::Web::Controller::Tapper::Schedule;
-BEGIN {
-  $Tapper::Reports::Web::Controller::Tapper::Schedule::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::Web::Controller::Tapper::Schedule::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Reports::Web::Controller::Tapper::Schedule::VERSION = '5.0.0';
 use strict;
 use warnings;
 use parent 'Catalyst::Controller';
@@ -26,9 +21,10 @@ $body
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -46,17 +42,26 @@ Tapper::Reports::Web::Controller::Tapper::Schedule - Catalyst Controller
 
 =head2 index
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
