@@ -1,11 +1,6 @@
 package Tapper::Reports::Web::Controller::Tapper::Testplan;
-BEGIN {
-  $Tapper::Reports::Web::Controller::Tapper::Testplan::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::Web::Controller::Tapper::Testplan::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Reports::Web::Controller::Tapper::Testplan::VERSION = '5.0.0';
 use parent 'Tapper::Reports::Web::Controller::Base';
 
 use common::sense;
@@ -88,7 +83,7 @@ sub index :Path :Args()
 
         $c->stash->{testplan_days} = [];
         my $today = DateTime::Format::Natural->new->parse_datetime("today at midnight");
-        my $dtf = $c->model("ReportsDB")->storage->datetime_parser;
+        my $dtf = $c->model("TestrunDB")->storage->datetime_parser;
 
         # testplans after "today at midnight"
         # handling them special makes later code more readable
@@ -140,11 +135,10 @@ sub get_testrun_details
 
         while ( my $instance = $todays_instances->next) {
 
-                my $details = {
-                               name => $instance->name,
-                               id   => $instance->id,
-                               path => $instance->path,
-                              };
+                my $details = {};
+                foreach my $col ($instance->columns) {
+                        $details->{$col} = $instance->$col;
+                }
                 $details->{count_unfinished} = int grep {$_->testrun_scheduling and
                                                            $_->testrun_scheduling->status ne 'finished'} $instance->testruns->all;
 
@@ -153,7 +147,7 @@ sub get_testrun_details
         TESTRUN:
                 while ( my $testrun = $testruns->next) {
                         next TESTRUN if $testrun->testrun_scheduling->status ne 'finished';
-                        my $stats   = model('ReportsDB')->resultset('ReportgroupTestrunStats')->search({testrun_id => $testrun->id}, {rows => 1})->first;
+                        my $stats   = model('TestrunDB')->resultset('ReportgroupTestrunStats')->search({testrun_id => $testrun->id}, {rows => 1})->first;
 
                         $details->{count_fail}++ if $stats and $stats->success_ratio  < 100;
                         $details->{count_pass}++ if $stats and $stats->success_ratio == 100;
@@ -240,9 +234,10 @@ sub prepare_navi : Private
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -280,17 +275,26 @@ AMD OSRC Tapper Team, C<< <tapper at amd64.org> >>
 
 This program is released under the following license: freebsd
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
