@@ -1,17 +1,13 @@
 package Tapper::Reports::Web::Controller::Tapper::Testruns::Id;
-BEGIN {
-  $Tapper::Reports::Web::Controller::Tapper::Testruns::Id::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::Web::Controller::Tapper::Testruns::Id::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Reports::Web::Controller::Tapper::Testruns::Id::VERSION = '5.0.0';
 use 5.010;
 
 use strict;
 use warnings;
 use Tapper::Model 'model';
 use Tapper::Reports::Web::Util::Report;
+use YAML::Syck;
 
 use parent 'Tapper::Reports::Web::Controller::Base';
 
@@ -46,7 +42,11 @@ sub index :Path :Args(1)
         $c->stash->{title} = "Testrun $testrun_id: ". $c->stash->{testrun}->topic_name . " @ ".$c->stash->{hostname};
         $c->stash->{overview} = $c->forward('/tapper/testruns/get_testrun_overview', [ $c->stash->{testrun} ]);
 
-        my $rgt_reports = $c->model('ReportsDB')->resultset('Report')->search
+        my @preconditions_hash = map { $_->precondition_as_hash } $c->stash->{testrun}->ordered_preconditions;
+        $YAML::Syck::SortKeys  = 1;
+        $c->stash->{precondition_string} = YAML::Syck::Dump(@preconditions_hash);
+
+        my $rgt_reports = $c->model('TestrunDB')->resultset('Report')->search
           (
            {
             "reportgrouptestrun.testrun_id" => $testrun_id
@@ -60,7 +60,7 @@ sub index :Path :Args(1)
         my $util_report = Tapper::Reports::Web::Util::Report->new();
 
         $c->stash->{reportlist_rgt} = $util_report->prepare_simple_reportlist($c,  $rgt_reports);
-        $c->stash->{report} = $c->model('ReportsDB')->resultset('Report')->search
+        $c->stash->{report} = $c->model('TestrunDB')->resultset('Report')->search
           (
            {
             "reportgrouptestrun.primaryreport" => 1,
@@ -129,25 +129,35 @@ sub prepare_navi : Private
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
 Tapper::Reports::Web::Controller::Tapper::Testruns::Id
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
