@@ -1,17 +1,12 @@
 package Tapper::Reports::Web::Model::TestrunDB;
-BEGIN {
-  $Tapper::Reports::Web::Model::TestrunDB::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::Web::Model::TestrunDB::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Reports::Web::Model::TestrunDB::VERSION = '5.0.0';
 use strict;
 use warnings;
 
 use Tapper::Config;
 
-use parent 'Catalyst::Model::DBIC::Schema';
+use parent 'Tapper::Reports::Web::Model';
 
 __PACKAGE__->config(
                     schema_class => 'Tapper::Schema::TestrunDB',
@@ -26,9 +21,10 @@ __PACKAGE__->config(
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -53,17 +49,26 @@ Steffen Schwigon,,,
 
 This program is released under the following license: freebsd
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
