@@ -1,10 +1,6 @@
 package Tapper::Reports::Web::Role::BehaviourModifications::Path;
-BEGIN {
-  $Tapper::Reports::Web::Role::BehaviourModifications::Path::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::Web::Role::BehaviourModifications::Path::VERSION = '4.1.2';
-}
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Reports::Web::Role::BehaviourModifications::Path::VERSION = '5.0.0';
 use Moose::Role;
 
 # I am sick of getting relocated/rebase on our local path!
@@ -22,25 +18,35 @@ after 'prepare_path' => sub {
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
 Tapper::Reports::Web::Role::BehaviourModifications::Path
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
