@@ -1,11 +1,6 @@
 package Tapper::Reports::Web::Util;
-BEGIN {
-  $Tapper::Reports::Web::Util::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::Web::Util::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Reports::Web::Util::VERSION = '5.0.0';
 use Moose;
 use strict;
 use warnings;
@@ -18,14 +13,14 @@ sub prepare_top_menu
 {
         my ($self, $active) = @_;
         my $top_menu = [
-                        {key => 'start',       text => 'Start',       uri => "/tapper/start/"},
-                        {key => 'reports',     text => 'Reports',     uri => "/tapper/reports/days/1"},
-                        {key => 'testruns',    text => 'Testruns',    uri => "/tapper/testruns/days/1"},
-                        {key => 'testplans',   text => 'Testplans',   uri => "/tapper/testplan/days/2"},
-                        {key => 'metareports', text => 'Metareports', uri => "/tapper/metareports/"},
-                        {key => 'manual',      text => 'Manual',      uri => "/tapper/manual/"},
-                        {key => 'user',        text => 'Login',       uri => "/tapper/user/login"},
-                       ];
+                { key => 'start',                text => 'Start',                uri => "/tapper/start/",            },
+                { key => 'reports',              text => 'Reports',              uri => "/tapper/reports",           },
+                { key => 'testruns',             text => 'Testruns',             uri => "/tapper/testruns",          },
+                { key => 'testplans',            text => 'Testplans',            uri => "/tapper/testplan",          },
+                { key => 'continuoustestruns',   text => 'Continuous Testruns',  uri => "/tapper/continuoustestruns",},
+                { key => 'metareports',          text => 'Metareports',          uri => "/tapper/metareports/",      },
+                { key => 'manual',               text => 'Manual',               uri => "/tapper/manual/",           },
+       ];
 
         # Some keys may be singular with their actions being named in plural or vice versa. Unify this.
         if ($active) {
@@ -41,11 +36,11 @@ sub prepare_top_menu
 
 1;
 
-
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -93,17 +88,26 @@ Copyright 2008-2011 AMD OSRC Tapper Team, all rights reserved.
 
 This program is released under the following license: freebsd
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
