@@ -1,11 +1,6 @@
 package Tapper::Reports::Web::Util::Filter;
-BEGIN {
-  $Tapper::Reports::Web::Util::Filter::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::Web::Util::Filter::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Reports::Web::Util::Filter::VERSION = '5.0.0';
 use DateTime;
 use Data::Dumper;
 use DateTime::Format::DateParse;
@@ -63,7 +58,7 @@ sub date
                 return $filter_condition;
         }
 
-        my $dtf = model("ReportsDB")->storage->datetime_parser;
+        my $dtf = model("TestrunDB")->storage->datetime_parser;
 
         $filter_condition->{date} = $requested_day->ymd('/');
         $self->requested_day($requested_day);
@@ -85,7 +80,7 @@ sub days
         my $requested_day  = $parser->parse_datetime("today at midnight");
         $self->requested_day($requested_day);
 
-        my $dtf = model("ReportsDB")->storage->datetime_parser;
+        my $dtf = model("TestrunDB")->storage->datetime_parser;
 
         my $yesterday = $parser->parse_datetime("today at midnight")->subtract(days => $days);
         $filter_condition->{early}->{created_at} = {'>' => $dtf->format_datetime($yesterday)};
@@ -122,9 +117,10 @@ sub parse_filters
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -167,17 +163,26 @@ necessarily all every time):
 
 @return hash ref
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
