@@ -1,11 +1,6 @@
 package Tapper::Reports::Web::Util::Filter::Overview;
-BEGIN {
-  $Tapper::Reports::Web::Util::Filter::Overview::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::Web::Util::Filter::Overview::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Reports::Web::Util::Filter::Overview::VERSION = '5.0.0';
 
 
 
@@ -38,7 +33,7 @@ sub weeks
         my ($self, $filter_condition, $duration) = @_;
 
         my $timeframe = DateTime->now->subtract(weeks => $duration);
-        my $dtf = model("ReportsDB")->storage->datetime_parser;
+        my $dtf = model("TestrunDB")->storage->datetime_parser;
         push @{$filter_condition->{late}}, {'reports.created_at' => {'>=' => $dtf->format_datetime($timeframe) }};
         return $filter_condition;
 }
@@ -70,9 +65,10 @@ sub hostname
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -121,17 +117,26 @@ accepted.
 
 Tapper::Reports::Web::Util::Filter::Overview - Filter utilities for overview listing
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
