@@ -1,11 +1,8 @@
 package Tapper::Reports::Web::Util::Filter::Report;
-BEGIN {
-  $Tapper::Reports::Web::Util::Filter::Report::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::Web::Util::Filter::Report::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Reports::Web::Util::Filter::Report::VERSION = '5.0.0';
+use strict;
+use warnings;
 
 
 
@@ -18,30 +15,24 @@ use Tapper::Model 'model';
 
 extends 'Tapper::Reports::Web::Util::Filter';
 
-sub BUILD{
+sub BUILD {
+
         my $self = shift;
         my $args = shift;
 
         $self->dispatch(
-                        merge($self->dispatch,
-                              {host    => \&host,
-                               suite   => \&suite,
-                               success => \&success,
-                               owner   => \&owner,
-                              })
-                       );
-}
+                merge(
+                        $self->dispatch,
+                        {
+                                suite       => \&suite,
+                                success     => \&success,
+                                owner       => sub { hr_set_filter_default( @_, 'owner' ); },
+                                host        => sub { hr_set_filter_default( @_, 'host' ); },
+                                idlist      => sub { hr_set_filter_default( @_, 'report_id' ); },
+                        }
+                )
+        );
 
-
-
-sub host
-{
-        my ($self, $filter_condition, $host) = @_;
-        my @hosts;
-        @hosts = @{$filter_condition->{early}->{machine_name}->{in}} if $filter_condition->{early}->{machine_name};
-        push @hosts, $host;
-        $filter_condition->{early}->{machine_name} = {'in' => \@hosts};
-        return $filter_condition;
 }
 
 
@@ -52,15 +43,15 @@ sub suite
         if ($suite =~/^\d+$/) {
                 $suite_id = $suite;
         } else {
-                my $suite_rs = $self->context->model('ReportsDB')->resultset('Suite')->search({name => $suite});
+                my $suite_rs = $self->context->model('TestrunDB')->resultset('Suite')->search({name => $suite});
                 $suite_id = $suite_rs->search({}, {rows => 1})->first->id if $suite_rs->count;
         }
 
         my @suites;
-        @suites = @{$filter_condition->{early}->{suite_id}->{in}} if $filter_condition->{suite_id};
+           @suites = @{$filter_condition->{suite_id}} if $filter_condition->{suite_id};
         push @suites, $suite_id;
 
-        $filter_condition->{early}->{suite_id} = {'in' => \@suites};
+        $filter_condition->{suite_id} = \@suites;
         return $filter_condition;
 }
 
@@ -68,36 +59,30 @@ sub suite
 sub success
 {
         my ($self, $filter_condition, $success) = @_;
-        if ($success =~/^\d+$/) {
-                $filter_condition->{early}->{success_ratio} = int($success);
-        } else {
-                $filter_condition->{early}->{successgrade} = uc($success);
+
+        if ( $success =~/^\d+$/ ) {
+                push @{$filter_condition->{success_ratio} ||= []}, int($success);
+        }
+        else {
+                push @{$filter_condition->{successgrade} ||= []}, uc($success);
         }
         return $filter_condition;
 
 }
 
-
-
-
-sub owner
-{
-        my ($self, $filter_condition, $owner) = @_;
-        push @{$filter_condition->{late}},
-        { '-or' => [
-                    {'reportgrouparbitrary.owner' => $owner},
-                    {'reportgrouptestrun.owner' => $owner},
-                   ]};
-
-        return $filter_condition;
+sub hr_set_filter_default {
+    my ( $or_self, $hr_filter, $value, $s_filter_name ) = @_;
+    push @{$hr_filter->{$s_filter_name} ||= []}, $value;
+    return $hr_filter;
 }
 
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -111,15 +96,6 @@ Tapper::Reports::Web::Util::Filter::Report
  my $allowed_filter_keys = ['host','days'];
  my $searchoptions       = $filter->parse_filters($filter_args, $allowed_filter_keys);
 
-=head2 host
-
-Add host filters to early filters.
-
-@param hash ref - current version of filters
-@param string   - host name
-
-@return hash ref - updated filters
-
 =head2 suite
 
 Add test suite to early filters.
@@ -139,30 +115,30 @@ ratio in percent.
 
 @return hash ref - updated filters
 
-=head2 owner
-
-Adds filters for owner. Currently, owners are only determind by testruns.
-
-@param hash ref - current version of filters
-@param string   - owner name
-
-@return hash ref - updated filters
-
 =head1 NAME
 
 Tapper::Reports::Web::Util::Filter::Report - Filter utilities for report listing
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
