@@ -1,11 +1,6 @@
 package Tapper::Reports::Web::Util::Filter::Testplan;
-BEGIN {
-  $Tapper::Reports::Web::Util::Filter::Testplan::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::Web::Util::Filter::Testplan::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Reports::Web::Util::Filter::Testplan::VERSION = '5.0.0';
 
 
 
@@ -56,9 +51,10 @@ sub name
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -95,17 +91,26 @@ Filter testplans for a given name.
 
 Tapper::Reports::Web::Util::Filter::Testplan - Filter utilities for testrun listing
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
