@@ -1,11 +1,6 @@
 package Tapper::Reports::Web::Util::Report;
-BEGIN {
-  $Tapper::Reports::Web::Util::Report::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::Web::Util::Report::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Reports::Web::Util::Report::VERSION = '5.0.0';
 use Moose;
 use Tapper::Model 'model';
 
@@ -13,15 +8,15 @@ extends 'Tapper::Reports::Web::Util';
 
 use common::sense;
 
+sub prepare_simple_reportlist {
 
-sub prepare_simple_reportlist
-{
         my ( $self, $c, $reports ) = @_;
 
         # Mnemonic:
         #           rga = ReportGroup Arbitrary
         #           rgt = ReportGroup Testrun
 
+        my $or_schema = model('TestrunDB');
         my @all_reports;
         my @reports;
         my %rgt;
@@ -46,20 +41,20 @@ sub prepare_simple_reportlist
                          created_at_ymd_hm     => sprintf("%s %02d:%02d",$report->created_at->ymd('-'), $report->created_at->hour, $report->created_at->minute),
                          created_at_ymd        => $report->created_at->ymd('-'),
                          success_ratio         => $report->success_ratio,
-                         successgrade          => $report->successgrade,
-                         reviewed_successgrade => $report->reviewed_successgrade,
+                         successgrade          => $report->parse_errors ? 'ERROR' : $report->successgrade,
                          total                 => $report->total,
                          rga_id                => $rga_id,
                          rga_primary           => $rga_primary,
                          rgt_id                => $rgt_id,
                          rgt_primary           => $rgt_primary,
+                         parse_errors          => $report->parse_errors,
                          peerport              => $report->peerport,
                          peeraddr              => $report->peeraddr,
                          peerhost              => $report->peerhost,
-                        };
+                };
 
                 # --- scheduling state ---
-                my $testrun_scheduling = model('TestrunDB')->resultset('TestrunScheduling')->search({testrun_id => $rgt_id}, {rows => 1})->first;
+                my $testrun_scheduling = $or_schema->resultset('TestrunScheduling')->search({testrun_id => $rgt_id}, {rows => 1})->first;
                 $r->{testrunscheduling_status} = $testrun_scheduling->status if $testrun_scheduling;
 
                 # --- arbitrary ---
@@ -125,32 +120,42 @@ sub prepare_simple_reportlist
                 reports     => \@reports,
                 rga         => \%rga,
                 rgt         => \%rgt,
-               };
+        };
 }
 
 
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
 Tapper::Reports::Web::Util::Report
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
