@@ -1,11 +1,6 @@
 package Tapper::Reports::Web::Util::Testrun;
-BEGIN {
-  $Tapper::Reports::Web::Util::Testrun::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::Web::Util::Testrun::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Reports::Web::Util::Testrun::VERSION = '5.0.0';
 use Moose;
 use Tapper::Model 'model';
 
@@ -73,9 +68,10 @@ sub prepare_testrunlist
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -100,17 +96,26 @@ hash contains:
 
 @return array ref - list of hash refs describing the testruns
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
