@@ -1,22 +1,19 @@
 package Tapper::Reports::Web::View::Mason;
-BEGIN {
-  $Tapper::Reports::Web::View::Mason::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::Web::View::Mason::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Reports::Web::View::Mason::VERSION = '5.0.0';
 use Moose;
 use namespace::autoclean;
 extends 'Catalyst::View::HTML::Mason';
 
-use File::ShareDir ':ALL';
 use Cwd;
+use File::ShareDir ':ALL';
 
-my $root_dir = [
-                [ tapperroot1 => getcwd."/root" ],
-                [ tapperroot2 => eval { dist_dir("Tapper-Reports-Web") } || getcwd."/root" ],
-               ];
+my $s_root_dir = $ENV{DOCUMENT_ROOT} || Cwd::getcwd . '/root';
+
+my $root_dir   = [
+    [ tapperroot1 => $s_root_dir ],
+    [ tapperroot2 => eval { dist_dir("Tapper-Reports-Web") } || $s_root_dir ],
+];
 
 __PACKAGE__->config({ template_extension => '.mas',
                       globals            => [['$c' => sub { $_[1] } ]],
@@ -46,9 +43,10 @@ sub my_url_filter
 # End:
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -75,17 +73,26 @@ Clever guy
 This library is free software . You can redistribute it and/or modify it under
 the same terms as perl itself.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
